@@ -15,37 +15,36 @@
 class Dataset {
 
 public:
+    typedef std::vector<uint64_t> Metrics;
+    typedef std::vector<uint64_t>* MetricsPtr;
+
     Dataset() : samplesInDataset(0),  metricNames(0) {};
 
     void addChunk(Chunk *pChunk);
-    void releaseChunks();
-    int mergeChunkMetrics();
-
     size_t getChunkCount() { return chunkVector.size(); }
     Chunk *getChunk(size_t n) { return (n < chunkVector.size()) ? chunkVector[n] : nullptr; }
     std::vector<Chunk *> getChunkVector() { return chunkVector; }
-
     size_t getMetricNames(std::vector< std::string> & metricNames);
-    size_t getMetricLength() { return samplesInDataset; }
-    std::vector<uint64_t>*getMetric(std::string metricName) { return hashMapMetrics[metricName]; }
-    std::map<std::string, std::vector<uint64_t>*> getHashMetrics() { return hashMapMetrics; }
+    [[nodiscard]] size_t getMetricLength() const { return samplesInDataset; }
+
+    MetricsPtr getMetric(std::string   metricName);
+
+    std::map<std::string, MetricsPtr> getHashMetrics() { return hashMapMetrics; }
     size_t getMetricNamesCount() { return metricNames.size(); }
-
-
+    void sortChunks();
     void FileParsed();
+    void   addMergedMetric(std::string   metricName, MetricsPtr data );
 
-    void   addMergedMetric(std::basic_string<char, std::char_traits<char>, std::allocator<char>> metricName, std::vector<uint64_t> *data );
 
 private:
-    int mergeChunkMetricsMT();
-    void sortChunks();
+    void releaseChunks();
 
+private:
     std::vector<Chunk*> chunkVector;
     size_t samplesInDataset;
     boost::mutex mu;
     std::vector<std::string> metricNames;
-    std::map<std::string, std::vector<uint64_t>*> hashMapMetrics;
-
+    std::map<std::string,  MetricsPtr>  hashMapMetrics;
 };
 
 
